"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.wrappers_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class ConnectorSpec(google.protobuf.message.Message):
    """An object that represents an Apache Kafka® connector.

    See [the documentation](/docs/managed-kafka/concepts/connectors) for details.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class PropertiesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    NAME_FIELD_NUMBER: builtins.int
    TASKS_MAX_FIELD_NUMBER: builtins.int
    PROPERTIES_FIELD_NUMBER: builtins.int
    CONNECTOR_CONFIG_MIRRORMAKER_FIELD_NUMBER: builtins.int
    CONNECTOR_CONFIG_S3_SINK_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Name of the connector."""
    @property
    def tasks_max(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Maximum number of connector tasks. Default value is the number of brokers."""

    @property
    def properties(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """A set of properties passed to Managed Service for Apache Kafka® with the connector configuration.
        Example: `sync.topics.config.enabled: true`.
        """

    @property
    def connector_config_mirrormaker(self) -> global___ConnectorConfigMirrorMakerSpec:
        """Configuration of the MirrorMaker connector."""

    @property
    def connector_config_s3_sink(self) -> global___ConnectorConfigS3SinkSpec:
        """Configuration of S3-Sink connector."""

    def __init__(
        self,
        *,
        name: builtins.str = ...,
        tasks_max: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        properties: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        connector_config_mirrormaker: global___ConnectorConfigMirrorMakerSpec | None = ...,
        connector_config_s3_sink: global___ConnectorConfigS3SinkSpec | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["connector_config", b"connector_config", "connector_config_mirrormaker", b"connector_config_mirrormaker", "connector_config_s3_sink", b"connector_config_s3_sink", "tasks_max", b"tasks_max"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["connector_config", b"connector_config", "connector_config_mirrormaker", b"connector_config_mirrormaker", "connector_config_s3_sink", b"connector_config_s3_sink", "name", b"name", "properties", b"properties", "tasks_max", b"tasks_max"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["connector_config", b"connector_config"]) -> typing.Literal["connector_config_mirrormaker", "connector_config_s3_sink"] | None: ...

global___ConnectorSpec = ConnectorSpec

@typing.final
class UpdateConnectorSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class PropertiesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    TASKS_MAX_FIELD_NUMBER: builtins.int
    PROPERTIES_FIELD_NUMBER: builtins.int
    CONNECTOR_CONFIG_MIRRORMAKER_FIELD_NUMBER: builtins.int
    CONNECTOR_CONFIG_S3_SINK_FIELD_NUMBER: builtins.int
    @property
    def tasks_max(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Maximum number of connector tasks to update."""

    @property
    def properties(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """A set of new or changed properties to update for the connector. They are passed with the connector configuration to Managed Service for Apache Kafka®.
        Example: `sync.topics.config.enabled: false`.
        """

    @property
    def connector_config_mirrormaker(self) -> global___ConnectorConfigMirrorMakerSpec:
        """Configuration of the MirrorMaker connector."""

    @property
    def connector_config_s3_sink(self) -> global___UpdateConnectorConfigS3SinkSpec:
        """Update specification for S3-Sink Connector."""

    def __init__(
        self,
        *,
        tasks_max: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        properties: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        connector_config_mirrormaker: global___ConnectorConfigMirrorMakerSpec | None = ...,
        connector_config_s3_sink: global___UpdateConnectorConfigS3SinkSpec | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["connector_config", b"connector_config", "connector_config_mirrormaker", b"connector_config_mirrormaker", "connector_config_s3_sink", b"connector_config_s3_sink", "tasks_max", b"tasks_max"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["connector_config", b"connector_config", "connector_config_mirrormaker", b"connector_config_mirrormaker", "connector_config_s3_sink", b"connector_config_s3_sink", "properties", b"properties", "tasks_max", b"tasks_max"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["connector_config", b"connector_config"]) -> typing.Literal["connector_config_mirrormaker", "connector_config_s3_sink"] | None: ...

global___UpdateConnectorSpec = UpdateConnectorSpec

@typing.final
class ConnectorConfigMirrorMakerSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SOURCE_CLUSTER_FIELD_NUMBER: builtins.int
    TARGET_CLUSTER_FIELD_NUMBER: builtins.int
    TOPICS_FIELD_NUMBER: builtins.int
    REPLICATION_FACTOR_FIELD_NUMBER: builtins.int
    topics: builtins.str
    """List of Kafka topics, separated by `,`."""
    @property
    def source_cluster(self) -> global___ClusterConnectionSpec:
        """Source cluster configuration for the MirrorMaker connector."""

    @property
    def target_cluster(self) -> global___ClusterConnectionSpec:
        """Target cluster configuration for the MirrorMaker connector."""

    @property
    def replication_factor(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Replication factor for automatically created topics."""

    def __init__(
        self,
        *,
        source_cluster: global___ClusterConnectionSpec | None = ...,
        target_cluster: global___ClusterConnectionSpec | None = ...,
        topics: builtins.str = ...,
        replication_factor: google.protobuf.wrappers_pb2.Int64Value | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["replication_factor", b"replication_factor", "source_cluster", b"source_cluster", "target_cluster", b"target_cluster"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["replication_factor", b"replication_factor", "source_cluster", b"source_cluster", "target_cluster", b"target_cluster", "topics", b"topics"]) -> None: ...

global___ConnectorConfigMirrorMakerSpec = ConnectorConfigMirrorMakerSpec

@typing.final
class ClusterConnectionSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ALIAS_FIELD_NUMBER: builtins.int
    THIS_CLUSTER_FIELD_NUMBER: builtins.int
    EXTERNAL_CLUSTER_FIELD_NUMBER: builtins.int
    alias: builtins.str
    """Alias of cluster connection configuration.
    Examples: `source`, `target`.
    """
    @property
    def this_cluster(self) -> global___ThisClusterSpec:
        """Connection configuration of the cluster the connector belongs to. As all credentials are already known, leave this parameter empty."""

    @property
    def external_cluster(self) -> global___ExternalClusterConnectionSpec:
        """Configuration of connection to an external cluster with all the necessary credentials."""

    def __init__(
        self,
        *,
        alias: builtins.str = ...,
        this_cluster: global___ThisClusterSpec | None = ...,
        external_cluster: global___ExternalClusterConnectionSpec | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["cluster_connection", b"cluster_connection", "external_cluster", b"external_cluster", "this_cluster", b"this_cluster"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["alias", b"alias", "cluster_connection", b"cluster_connection", "external_cluster", b"external_cluster", "this_cluster", b"this_cluster"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["cluster_connection", b"cluster_connection"]) -> typing.Literal["this_cluster", "external_cluster"] | None: ...

global___ClusterConnectionSpec = ClusterConnectionSpec

@typing.final
class ThisClusterSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___ThisClusterSpec = ThisClusterSpec

@typing.final
class ExternalClusterConnectionSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BOOTSTRAP_SERVERS_FIELD_NUMBER: builtins.int
    SASL_USERNAME_FIELD_NUMBER: builtins.int
    SASL_PASSWORD_FIELD_NUMBER: builtins.int
    SASL_MECHANISM_FIELD_NUMBER: builtins.int
    SECURITY_PROTOCOL_FIELD_NUMBER: builtins.int
    SSL_TRUSTSTORE_CERTIFICATES_FIELD_NUMBER: builtins.int
    bootstrap_servers: builtins.str
    """List of bootstrap servers of the cluster, separated by `,`."""
    sasl_username: builtins.str
    """SASL username to use for connection to the cluster."""
    sasl_password: builtins.str
    """SASL password to use for connection to the cluster."""
    sasl_mechanism: builtins.str
    """SASL mechanism to use for connection to the cluster."""
    security_protocol: builtins.str
    """Security protocol to use for connection to the cluster."""
    ssl_truststore_certificates: builtins.str
    """CA in PEM format to connect to external cluster.
    Lines of certificate separated by '\\n' symbol.
    """
    def __init__(
        self,
        *,
        bootstrap_servers: builtins.str = ...,
        sasl_username: builtins.str = ...,
        sasl_password: builtins.str = ...,
        sasl_mechanism: builtins.str = ...,
        security_protocol: builtins.str = ...,
        ssl_truststore_certificates: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["bootstrap_servers", b"bootstrap_servers", "sasl_mechanism", b"sasl_mechanism", "sasl_password", b"sasl_password", "sasl_username", b"sasl_username", "security_protocol", b"security_protocol", "ssl_truststore_certificates", b"ssl_truststore_certificates"]) -> None: ...

global___ExternalClusterConnectionSpec = ExternalClusterConnectionSpec

@typing.final
class ConnectorConfigS3SinkSpec(google.protobuf.message.Message):
    """Specification for Kafka S3-Sink Connector."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TOPICS_FIELD_NUMBER: builtins.int
    FILE_COMPRESSION_TYPE_FIELD_NUMBER: builtins.int
    FILE_MAX_RECORDS_FIELD_NUMBER: builtins.int
    S3_CONNECTION_FIELD_NUMBER: builtins.int
    topics: builtins.str
    """List of Kafka topics, separated by ','."""
    file_compression_type: builtins.str
    """The compression type used for files put on GCS.
    The supported values are: `gzip`, `snappy`, `zstd`, `none`.
    Optional, the default is `none`.
    """
    @property
    def file_max_records(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Max records per file."""

    @property
    def s3_connection(self) -> global___S3ConnectionSpec:
        """Credentials for connecting to S3 storage."""

    def __init__(
        self,
        *,
        topics: builtins.str = ...,
        file_compression_type: builtins.str = ...,
        file_max_records: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        s3_connection: global___S3ConnectionSpec | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["file_max_records", b"file_max_records", "s3_connection", b"s3_connection"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["file_compression_type", b"file_compression_type", "file_max_records", b"file_max_records", "s3_connection", b"s3_connection", "topics", b"topics"]) -> None: ...

global___ConnectorConfigS3SinkSpec = ConnectorConfigS3SinkSpec

@typing.final
class UpdateConnectorConfigS3SinkSpec(google.protobuf.message.Message):
    """Specification for update Kafka S3-Sink Connector."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TOPICS_FIELD_NUMBER: builtins.int
    FILE_MAX_RECORDS_FIELD_NUMBER: builtins.int
    S3_CONNECTION_FIELD_NUMBER: builtins.int
    topics: builtins.str
    """List of Kafka topics, separated by ','."""
    @property
    def file_max_records(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Max records per file."""

    @property
    def s3_connection(self) -> global___S3ConnectionSpec:
        """Credentials for connecting to S3 storage."""

    def __init__(
        self,
        *,
        topics: builtins.str = ...,
        file_max_records: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        s3_connection: global___S3ConnectionSpec | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["file_max_records", b"file_max_records", "s3_connection", b"s3_connection"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["file_max_records", b"file_max_records", "s3_connection", b"s3_connection", "topics", b"topics"]) -> None: ...

global___UpdateConnectorConfigS3SinkSpec = UpdateConnectorConfigS3SinkSpec

@typing.final
class S3ConnectionSpec(google.protobuf.message.Message):
    """Specification for S3Connection -
    settings of connection to AWS-compatible S3 storage, that
    are source or target of Kafka S3-connectors.
    YC Object Storage is AWS-compatible.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUCKET_NAME_FIELD_NUMBER: builtins.int
    EXTERNAL_S3_FIELD_NUMBER: builtins.int
    bucket_name: builtins.str
    @property
    def external_s3(self) -> global___ExternalS3StorageSpec: ...
    def __init__(
        self,
        *,
        bucket_name: builtins.str = ...,
        external_s3: global___ExternalS3StorageSpec | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["external_s3", b"external_s3", "storage", b"storage"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["bucket_name", b"bucket_name", "external_s3", b"external_s3", "storage", b"storage"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["storage", b"storage"]) -> typing.Literal["external_s3"] | None: ...

global___S3ConnectionSpec = S3ConnectionSpec

@typing.final
class ExternalS3StorageSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACCESS_KEY_ID_FIELD_NUMBER: builtins.int
    SECRET_ACCESS_KEY_FIELD_NUMBER: builtins.int
    ENDPOINT_FIELD_NUMBER: builtins.int
    REGION_FIELD_NUMBER: builtins.int
    access_key_id: builtins.str
    secret_access_key: builtins.str
    endpoint: builtins.str
    region: builtins.str
    """Default is 'us-east-1'."""
    def __init__(
        self,
        *,
        access_key_id: builtins.str = ...,
        secret_access_key: builtins.str = ...,
        endpoint: builtins.str = ...,
        region: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["access_key_id", b"access_key_id", "endpoint", b"endpoint", "region", b"region", "secret_access_key", b"secret_access_key"]) -> None: ...

global___ExternalS3StorageSpec = ExternalS3StorageSpec

@typing.final
class Connector(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Health:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _HealthEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Connector._Health.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        HEALTH_UNKNOWN: Connector._Health.ValueType  # 0
        """Health of the connector is unknown."""
        ALIVE: Connector._Health.ValueType  # 1
        """Connector is running."""
        DEAD: Connector._Health.ValueType  # 2
        """Connector has failed to start."""

    class Health(_Health, metaclass=_HealthEnumTypeWrapper): ...
    HEALTH_UNKNOWN: Connector.Health.ValueType  # 0
    """Health of the connector is unknown."""
    ALIVE: Connector.Health.ValueType  # 1
    """Connector is running."""
    DEAD: Connector.Health.ValueType  # 2
    """Connector has failed to start."""

    class _Status:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _StatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Connector._Status.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        STATUS_UNKNOWN: Connector._Status.ValueType  # 0
        """Connector state is unknown."""
        RUNNING: Connector._Status.ValueType  # 1
        """Connector is running normally."""
        ERROR: Connector._Status.ValueType  # 2
        """Connector has encountered a problem and cannot operate."""
        PAUSED: Connector._Status.ValueType  # 3
        """Connector is paused."""

    class Status(_Status, metaclass=_StatusEnumTypeWrapper): ...
    STATUS_UNKNOWN: Connector.Status.ValueType  # 0
    """Connector state is unknown."""
    RUNNING: Connector.Status.ValueType  # 1
    """Connector is running normally."""
    ERROR: Connector.Status.ValueType  # 2
    """Connector has encountered a problem and cannot operate."""
    PAUSED: Connector.Status.ValueType  # 3
    """Connector is paused."""

    @typing.final
    class PropertiesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    NAME_FIELD_NUMBER: builtins.int
    TASKS_MAX_FIELD_NUMBER: builtins.int
    PROPERTIES_FIELD_NUMBER: builtins.int
    HEALTH_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    CLUSTER_ID_FIELD_NUMBER: builtins.int
    CONNECTOR_CONFIG_MIRRORMAKER_FIELD_NUMBER: builtins.int
    CONNECTOR_CONFIG_S3_SINK_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Name of the connector."""
    health: global___Connector.Health.ValueType
    """Connector health."""
    status: global___Connector.Status.ValueType
    """Current status of the connector."""
    cluster_id: builtins.str
    """ID of the Apache Kafka® cluster that the connector belongs to."""
    @property
    def tasks_max(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Maximum number of connector tasks. Default value is the number of brokers."""

    @property
    def properties(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """A set of properties passed to Managed Service for Apache Kafka® with the connector configuration.
        Example: `sync.topics.config.enabled: true`.
        """

    @property
    def connector_config_mirrormaker(self) -> global___ConnectorConfigMirrorMaker:
        """Configuration of the MirrorMaker connector."""

    @property
    def connector_config_s3_sink(self) -> global___ConnectorConfigS3Sink:
        """Configuration of S3-Sink connector."""

    def __init__(
        self,
        *,
        name: builtins.str = ...,
        tasks_max: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        properties: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        health: global___Connector.Health.ValueType = ...,
        status: global___Connector.Status.ValueType = ...,
        cluster_id: builtins.str = ...,
        connector_config_mirrormaker: global___ConnectorConfigMirrorMaker | None = ...,
        connector_config_s3_sink: global___ConnectorConfigS3Sink | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["connector_config", b"connector_config", "connector_config_mirrormaker", b"connector_config_mirrormaker", "connector_config_s3_sink", b"connector_config_s3_sink", "tasks_max", b"tasks_max"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "connector_config", b"connector_config", "connector_config_mirrormaker", b"connector_config_mirrormaker", "connector_config_s3_sink", b"connector_config_s3_sink", "health", b"health", "name", b"name", "properties", b"properties", "status", b"status", "tasks_max", b"tasks_max"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["connector_config", b"connector_config"]) -> typing.Literal["connector_config_mirrormaker", "connector_config_s3_sink"] | None: ...

global___Connector = Connector

@typing.final
class ConnectorConfigMirrorMaker(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SOURCE_CLUSTER_FIELD_NUMBER: builtins.int
    TARGET_CLUSTER_FIELD_NUMBER: builtins.int
    TOPICS_FIELD_NUMBER: builtins.int
    REPLICATION_FACTOR_FIELD_NUMBER: builtins.int
    topics: builtins.str
    """List of Kafka topics, separated by `,`."""
    @property
    def source_cluster(self) -> global___ClusterConnection:
        """Source cluster connection configuration."""

    @property
    def target_cluster(self) -> global___ClusterConnection:
        """Target cluster connection configuration."""

    @property
    def replication_factor(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Replication factor for automatically created topics."""

    def __init__(
        self,
        *,
        source_cluster: global___ClusterConnection | None = ...,
        target_cluster: global___ClusterConnection | None = ...,
        topics: builtins.str = ...,
        replication_factor: google.protobuf.wrappers_pb2.Int64Value | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["replication_factor", b"replication_factor", "source_cluster", b"source_cluster", "target_cluster", b"target_cluster"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["replication_factor", b"replication_factor", "source_cluster", b"source_cluster", "target_cluster", b"target_cluster", "topics", b"topics"]) -> None: ...

global___ConnectorConfigMirrorMaker = ConnectorConfigMirrorMaker

@typing.final
class ClusterConnection(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ALIAS_FIELD_NUMBER: builtins.int
    THIS_CLUSTER_FIELD_NUMBER: builtins.int
    EXTERNAL_CLUSTER_FIELD_NUMBER: builtins.int
    alias: builtins.str
    """Alias of cluster connection configuration.
    Examples: `source`, `target`.
    """
    @property
    def this_cluster(self) -> global___ThisCluster:
        """Connection configuration of the cluster the connector belongs to. As all credentials are already known, leave this parameter empty."""

    @property
    def external_cluster(self) -> global___ExternalClusterConnection:
        """Configuration of connection to an external cluster with all the necessary credentials."""

    def __init__(
        self,
        *,
        alias: builtins.str = ...,
        this_cluster: global___ThisCluster | None = ...,
        external_cluster: global___ExternalClusterConnection | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["cluster_connection", b"cluster_connection", "external_cluster", b"external_cluster", "this_cluster", b"this_cluster"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["alias", b"alias", "cluster_connection", b"cluster_connection", "external_cluster", b"external_cluster", "this_cluster", b"this_cluster"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["cluster_connection", b"cluster_connection"]) -> typing.Literal["this_cluster", "external_cluster"] | None: ...

global___ClusterConnection = ClusterConnection

@typing.final
class ThisCluster(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___ThisCluster = ThisCluster

@typing.final
class ExternalClusterConnection(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BOOTSTRAP_SERVERS_FIELD_NUMBER: builtins.int
    SASL_USERNAME_FIELD_NUMBER: builtins.int
    SASL_MECHANISM_FIELD_NUMBER: builtins.int
    SECURITY_PROTOCOL_FIELD_NUMBER: builtins.int
    bootstrap_servers: builtins.str
    """List of bootstrap servers of the cluster, separated by `,`."""
    sasl_username: builtins.str
    """SASL username to use for connection to the cluster."""
    sasl_mechanism: builtins.str
    """SASL mechanism to use for connection to the cluster."""
    security_protocol: builtins.str
    """Security protocol to use for connection to the cluster."""
    def __init__(
        self,
        *,
        bootstrap_servers: builtins.str = ...,
        sasl_username: builtins.str = ...,
        sasl_mechanism: builtins.str = ...,
        security_protocol: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["bootstrap_servers", b"bootstrap_servers", "sasl_mechanism", b"sasl_mechanism", "sasl_username", b"sasl_username", "security_protocol", b"security_protocol"]) -> None: ...

global___ExternalClusterConnection = ExternalClusterConnection

@typing.final
class ConnectorConfigS3Sink(google.protobuf.message.Message):
    """An Apache Kafka® S3-Sink
    connector resource.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TOPICS_FIELD_NUMBER: builtins.int
    FILE_COMPRESSION_TYPE_FIELD_NUMBER: builtins.int
    FILE_MAX_RECORDS_FIELD_NUMBER: builtins.int
    S3_CONNECTION_FIELD_NUMBER: builtins.int
    topics: builtins.str
    """List of Kafka topics, separated by ','."""
    file_compression_type: builtins.str
    """The compression type used for files put on GCS.
    The supported values are: `gzip`, `snappy`, `zstd`, `none`.
    Optional, the default is `none`.
    """
    @property
    def file_max_records(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Max records per file."""

    @property
    def s3_connection(self) -> global___S3Connection:
        """Credentials for connecting to S3 storage."""

    def __init__(
        self,
        *,
        topics: builtins.str = ...,
        file_compression_type: builtins.str = ...,
        file_max_records: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        s3_connection: global___S3Connection | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["file_max_records", b"file_max_records", "s3_connection", b"s3_connection"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["file_compression_type", b"file_compression_type", "file_max_records", b"file_max_records", "s3_connection", b"s3_connection", "topics", b"topics"]) -> None: ...

global___ConnectorConfigS3Sink = ConnectorConfigS3Sink

@typing.final
class S3Connection(google.protobuf.message.Message):
    """Resource for S3Connection -
    settings of connection to AWS-compatible S3 storage, that
    are source or target of Kafka S3-connectors.
    YC Object Storage is AWS-compatible.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUCKET_NAME_FIELD_NUMBER: builtins.int
    EXTERNAL_S3_FIELD_NUMBER: builtins.int
    bucket_name: builtins.str
    @property
    def external_s3(self) -> global___ExternalS3Storage: ...
    def __init__(
        self,
        *,
        bucket_name: builtins.str = ...,
        external_s3: global___ExternalS3Storage | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["external_s3", b"external_s3", "storage", b"storage"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["bucket_name", b"bucket_name", "external_s3", b"external_s3", "storage", b"storage"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["storage", b"storage"]) -> typing.Literal["external_s3"] | None: ...

global___S3Connection = S3Connection

@typing.final
class ExternalS3Storage(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACCESS_KEY_ID_FIELD_NUMBER: builtins.int
    ENDPOINT_FIELD_NUMBER: builtins.int
    REGION_FIELD_NUMBER: builtins.int
    access_key_id: builtins.str
    endpoint: builtins.str
    region: builtins.str
    """Default is 'us-east-1'"""
    def __init__(
        self,
        *,
        access_key_id: builtins.str = ...,
        endpoint: builtins.str = ...,
        region: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["access_key_id", b"access_key_id", "endpoint", b"endpoint", "region", b"region"]) -> None: ...

global___ExternalS3Storage = ExternalS3Storage



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/connectionmanager/v1/connection_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/connectionmanager/v1/connection_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud.connectionmanager.v1 import connection_pb2 as yandex_dot_cloud_dot_connectionmanager_dot_v1_dot_connection__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n:yandex/cloud/connectionmanager/v1/connection_service.proto\x12!yandex.cloud.connectionmanager.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x32yandex/cloud/connectionmanager/v1/connection.proto\"\xa1\x02\n\x17\x43reateConnectionRequest\x12\x11\n\tfolder_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12V\n\x06labels\x18\x04 \x03(\x0b\x32\x46.yandex.cloud.connectionmanager.v1.CreateConnectionRequest.LabelsEntry\x12\x43\n\x06params\x18\x05 \x01(\x0b\x32\x33.yandex.cloud.connectionmanager.v1.ConnectionParams\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01J\x04\x08\x06\x10\x0b\"1\n\x18\x43reateConnectionMetadata\x12\x15\n\rconnection_id\x18\x01 \x01(\t\"\xd6\x02\n\x17UpdateConnectionRequest\x12\x15\n\rconnection_id\x18\x01 \x01(\t\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12V\n\x06labels\x18\x05 \x03(\x0b\x32\x46.yandex.cloud.connectionmanager.v1.UpdateConnectionRequest.LabelsEntry\x12\x43\n\x06params\x18\x06 \x01(\x0b\x32\x33.yandex.cloud.connectionmanager.v1.ConnectionParams\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01J\x04\x08\x07\x10\n\"1\n\x18UpdateConnectionMetadata\x12\x15\n\rconnection_id\x18\x01 \x01(\t\"0\n\x17\x44\x65leteConnectionRequest\x12\x15\n\rconnection_id\x18\x01 \x01(\t\"\x1a\n\x18\x44\x65leteConnectionMetadata\"\xd1\x02\n\x15ListConnectionRequest\x12\x11\n\tfolder_id\x18\x01 \x01(\t\x12\x16\n\x0emdb_cluster_id\x18\x02 \x01(\t\x12\x11\n\tpage_size\x18\x04 \x01(\x03\x12\x12\n\npage_token\x18\x05 \x01(\t\x12\x1a\n\x12name_pattern_or_id\x18\x06 \x01(\t\x12\x11\n\tauthor_id\x18\x07 \x01(\t\x12\x14\n\x0cwith_can_use\x18\x08 \x01(\x08\x12\x30\n\x0cis_onpremise\x18\t \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12-\n\tis_manual\x18\n \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12:\n\x07\x64\x62_type\x18\x0b \x01(\x0e\x32).yandex.cloud.connectionmanager.v1.DBTypeJ\x04\x08\x03\x10\x04\"t\n\x16ListConnectionResponse\x12\x41\n\nconnection\x18\x01 \x03(\x0b\x32-.yandex.cloud.connectionmanager.v1.Connection\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"9\n\x14GetConnectionRequest\x12\x15\n\rconnection_id\x18\x01 \x01(\tJ\x04\x08\x02\x10\x03J\x04\x08\x03\x10\x04\"4\n\x15ResolveClusterRequest\x12\x15\n\rconnection_id\x18\x01 \x01(\tJ\x04\x08\x02\x10\x03\"B\n\x15\x44\x65leteVersionMetadata\x12\x15\n\rconnection_id\x18\x01 \x01(\t\x12\x12\n\nversion_id\x18\x02 \x01(\t\"U\n\x15ListOperationsRequest\x12\x15\n\rconnection_id\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x03\x12\x12\n\npage_token\x18\x03 \x01(\t\"h\n\x16ListOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\xca\t\n\x11\x43onnectionService\x12\x95\x01\n\x03Get\x12\x37.yandex.cloud.connectionmanager.v1.GetConnectionRequest\x1a-.yandex.cloud.connectionmanager.v1.Connection\"&\x82\xd3\xe4\x93\x02 \x12\x1e/v1/connection/{connection_id}\x12\xb0\x01\n\x0eResolveCluster\x12\x38.yandex.cloud.connectionmanager.v1.ResolveClusterRequest\x1a-.yandex.cloud.connectionmanager.v1.Connection\"5\x82\xd3\xe4\x93\x02/\x12-/v1/connection/resolveCluster/{connection_id}\x12\x94\x01\n\x04List\x12\x38.yandex.cloud.connectionmanager.v1.ListConnectionRequest\x1a\x39.yandex.cloud.connectionmanager.v1.ListConnectionResponse\"\x17\x82\xd3\xe4\x93\x02\x11\x12\x0f/v1/connections\x12\xac\x01\n\x06\x43reate\x12:.yandex.cloud.connectionmanager.v1.CreateConnectionRequest\x1a!.yandex.cloud.operation.Operation\"C\xb2\xd2*&\n\x18\x43reateConnectionMetadata\x12\nConnection\x82\xd3\xe4\x93\x02\x13\"\x0e/v1/connection:\x01*\x12\xbc\x01\n\x06Update\x12:.yandex.cloud.connectionmanager.v1.UpdateConnectionRequest\x1a!.yandex.cloud.operation.Operation\"S\xb2\xd2*&\n\x18UpdateConnectionMetadata\x12\nConnection\x82\xd3\xe4\x93\x02#2\x1e/v1/connection/{connection_id}:\x01*\x12\xc4\x01\n\x06\x44\x65lete\x12:.yandex.cloud.connectionmanager.v1.DeleteConnectionRequest\x1a!.yandex.cloud.operation.Operation\"[\xb2\xd2*1\n\x18\x44\x65leteConnectionMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02 *\x1e/v1/connection/{connection_id}\x12\x9d\x01\n\x0eListOperations\x12\x38.yandex.cloud.connectionmanager.v1.ListOperationsRequest\x1a\x39.yandex.cloud.connectionmanager.v1.ListOperationsResponse\"\x16\x82\xd3\xe4\x93\x02\x10\x12\x0e/v1/operationsB\x80\x01\n%yandex.cloud.api.connectionmanager.v1ZWgithub.com/yandex-cloud/go-genproto/yandex/cloud/connectionmanager/v1;connectionmanagerb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.connectionmanager.v1.connection_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n%yandex.cloud.api.connectionmanager.v1ZWgithub.com/yandex-cloud/go-genproto/yandex/cloud/connectionmanager/v1;connectionmanager'
  _globals['_CREATECONNECTIONREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_CREATECONNECTIONREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_UPDATECONNECTIONREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_UPDATECONNECTIONREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_CONNECTIONSERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_CONNECTIONSERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\002 \022\036/v1/connection/{connection_id}'
  _globals['_CONNECTIONSERVICE'].methods_by_name['ResolveCluster']._loaded_options = None
  _globals['_CONNECTIONSERVICE'].methods_by_name['ResolveCluster']._serialized_options = b'\202\323\344\223\002/\022-/v1/connection/resolveCluster/{connection_id}'
  _globals['_CONNECTIONSERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_CONNECTIONSERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\002\021\022\017/v1/connections'
  _globals['_CONNECTIONSERVICE'].methods_by_name['Create']._loaded_options = None
  _globals['_CONNECTIONSERVICE'].methods_by_name['Create']._serialized_options = b'\262\322*&\n\030CreateConnectionMetadata\022\nConnection\202\323\344\223\002\023\"\016/v1/connection:\001*'
  _globals['_CONNECTIONSERVICE'].methods_by_name['Update']._loaded_options = None
  _globals['_CONNECTIONSERVICE'].methods_by_name['Update']._serialized_options = b'\262\322*&\n\030UpdateConnectionMetadata\022\nConnection\202\323\344\223\002#2\036/v1/connection/{connection_id}:\001*'
  _globals['_CONNECTIONSERVICE'].methods_by_name['Delete']._loaded_options = None
  _globals['_CONNECTIONSERVICE'].methods_by_name['Delete']._serialized_options = b'\262\322*1\n\030DeleteConnectionMetadata\022\025google.protobuf.Empty\202\323\344\223\002 *\036/v1/connection/{connection_id}'
  _globals['_CONNECTIONSERVICE'].methods_by_name['ListOperations']._loaded_options = None
  _globals['_CONNECTIONSERVICE'].methods_by_name['ListOperations']._serialized_options = b'\202\323\344\223\002\020\022\016/v1/operations'
  _globals['_CREATECONNECTIONREQUEST']._serialized_start=320
  _globals['_CREATECONNECTIONREQUEST']._serialized_end=609
  _globals['_CREATECONNECTIONREQUEST_LABELSENTRY']._serialized_start=558
  _globals['_CREATECONNECTIONREQUEST_LABELSENTRY']._serialized_end=603
  _globals['_CREATECONNECTIONMETADATA']._serialized_start=611
  _globals['_CREATECONNECTIONMETADATA']._serialized_end=660
  _globals['_UPDATECONNECTIONREQUEST']._serialized_start=663
  _globals['_UPDATECONNECTIONREQUEST']._serialized_end=1005
  _globals['_UPDATECONNECTIONREQUEST_LABELSENTRY']._serialized_start=558
  _globals['_UPDATECONNECTIONREQUEST_LABELSENTRY']._serialized_end=603
  _globals['_UPDATECONNECTIONMETADATA']._serialized_start=1007
  _globals['_UPDATECONNECTIONMETADATA']._serialized_end=1056
  _globals['_DELETECONNECTIONREQUEST']._serialized_start=1058
  _globals['_DELETECONNECTIONREQUEST']._serialized_end=1106
  _globals['_DELETECONNECTIONMETADATA']._serialized_start=1108
  _globals['_DELETECONNECTIONMETADATA']._serialized_end=1134
  _globals['_LISTCONNECTIONREQUEST']._serialized_start=1137
  _globals['_LISTCONNECTIONREQUEST']._serialized_end=1474
  _globals['_LISTCONNECTIONRESPONSE']._serialized_start=1476
  _globals['_LISTCONNECTIONRESPONSE']._serialized_end=1592
  _globals['_GETCONNECTIONREQUEST']._serialized_start=1594
  _globals['_GETCONNECTIONREQUEST']._serialized_end=1651
  _globals['_RESOLVECLUSTERREQUEST']._serialized_start=1653
  _globals['_RESOLVECLUSTERREQUEST']._serialized_end=1705
  _globals['_DELETEVERSIONMETADATA']._serialized_start=1707
  _globals['_DELETEVERSIONMETADATA']._serialized_end=1773
  _globals['_LISTOPERATIONSREQUEST']._serialized_start=1775
  _globals['_LISTOPERATIONSREQUEST']._serialized_end=1860
  _globals['_LISTOPERATIONSRESPONSE']._serialized_start=1862
  _globals['_LISTOPERATIONSRESPONSE']._serialized_end=1966
  _globals['_CONNECTIONSERVICE']._serialized_start=1969
  _globals['_CONNECTIONSERVICE']._serialized_end=3195
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/dataproc/v1/common.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/dataproc/v1/common.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%yandex/cloud/dataproc/v1/common.proto\x12\x18yandex.cloud.dataproc.v1\"P\n\tResources\x12\x1a\n\x12resource_preset_id\x18\x01 \x01(\t\x12\x14\n\x0c\x64isk_type_id\x18\x02 \x01(\t\x12\x11\n\tdisk_size\x18\x03 \x01(\x03*?\n\x06Health\x12\x12\n\x0eHEALTH_UNKNOWN\x10\x00\x12\t\n\x05\x41LIVE\x10\x01\x12\x08\n\x04\x44\x45\x41\x44\x10\x02\x12\x0c\n\x08\x44\x45GRADED\x10\x03\x42\x65\n\x1cyandex.cloud.api.dataproc.v1ZEgithub.com/yandex-cloud/go-genproto/yandex/cloud/dataproc/v1;dataprocb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.dataproc.v1.common_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\034yandex.cloud.api.dataproc.v1ZEgithub.com/yandex-cloud/go-genproto/yandex/cloud/dataproc/v1;dataproc'
  _globals['_HEALTH']._serialized_start=149
  _globals['_HEALTH']._serialized_end=212
  _globals['_RESOURCES']._serialized_start=67
  _globals['_RESOURCES']._serialized_end=147
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/spark/v1/cluster_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/spark/v1/cluster_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.spark.v1 import cluster_pb2 as yandex_dot_cloud_dot_spark_dot_v1_dot_cluster__pb2
from yandex.cloud.spark.v1 import maintenance_pb2 as yandex_dot_cloud_dot_spark_dot_v1_dot_maintenance__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+yandex/cloud/spark/v1/cluster_service.proto\x12\x15yandex.cloud.spark.v1\x1a google/protobuf/field_mask.proto\x1a#yandex/cloud/spark/v1/cluster.proto\x1a\'yandex/cloud/spark/v1/maintenance.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\x1a yandex/cloud/api/operation.proto\"5\n\x11GetClusterRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\x90\x01\n\x13ListClustersRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=200\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"l\n\x14ListClustersResponse\x12\x30\n\x08\x63lusters\x18\x01 \x03(\x0b\x32\x1e.yandex.cloud.spark.v1.Cluster\x12\"\n\x0fnext_page_token\x18\x02 \x01(\tB\t\x8a\xc8\x31\x05<=200\"\x88\x05\n\x14\x43reateClusterRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12<\n\x04name\x18\x02 \x01(\tB.\xe8\xc7\x31\x01\xf2\xc7\x31\x1e^[a-z][-a-z0-9]{1,61}[a-z0-9]$\x8a\xc8\x31\x04<=63\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x84\x01\n\x06labels\x18\x04 \x03(\x0b\x32\x37.yandex.cloud.spark.v1.CreateClusterRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04\x31-63\x12:\n\x06\x63onfig\x18\x05 \x01(\x0b\x32$.yandex.cloud.spark.v1.ClusterConfigB\x04\xe8\xc7\x31\x01\x12;\n\x07network\x18\x06 \x01(\x0b\x32$.yandex.cloud.spark.v1.NetworkConfigB\x04\xe8\xc7\x31\x01\x12\x1b\n\x13\x64\x65letion_protection\x18\x07 \x01(\x08\x12(\n\x12service_account_id\x18\x08 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x35\n\x07logging\x18\t \x01(\x0b\x32$.yandex.cloud.spark.v1.LoggingConfig\x12\x44\n\x12maintenance_window\x18\n \x01(\x0b\x32(.yandex.cloud.spark.v1.MaintenanceWindow\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"1\n\x15\x43reateClusterMetadata\x12\x18\n\ncluster_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"\xbb\x05\n\x14UpdateClusterRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12/\n\x04name\x18\x03 \x01(\tB!\xf2\xc7\x31\x1d|[a-z][-a-z0-9]{1,61}[a-z0-9]\x12\x1e\n\x0b\x64\x65scription\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x84\x01\n\x06labels\x18\x05 \x03(\x0b\x32\x37.yandex.cloud.spark.v1.UpdateClusterRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04\x31-63\x12\x43\n\x0b\x63onfig_spec\x18\x06 \x01(\x0b\x32..yandex.cloud.spark.v1.UpdateClusterConfigSpec\x12\x44\n\x0cnetwork_spec\x18\x07 \x01(\x0b\x32..yandex.cloud.spark.v1.UpdateNetworkConfigSpec\x12\x1b\n\x13\x64\x65letion_protection\x18\x08 \x01(\x08\x12$\n\x12service_account_id\x18\t \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x35\n\x07logging\x18\n \x01(\x0b\x32$.yandex.cloud.spark.v1.LoggingConfig\x12\x44\n\x12maintenance_window\x18\x0b \x01(\x0b\x32(.yandex.cloud.spark.v1.MaintenanceWindow\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"9\n\x15UpdateClusterMetadata\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"8\n\x14\x44\x65leteClusterRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"1\n\x15\x44\x65leteClusterMetadata\x12\x18\n\ncluster_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"7\n\x13StartClusterRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"*\n\x14StartClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\"6\n\x12StopClusterRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\")\n\x13StopClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\"~\n\x1cListClusterOperationsRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=200\"z\n\x1dListClusterOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\"\n\x0fnext_page_token\x18\x02 \x01(\tB\t\x8a\xc8\x31\x05<=2002\xcb\x07\n\x0e\x43lusterService\x12Q\n\x03Get\x12(.yandex.cloud.spark.v1.GetClusterRequest\x1a\x1e.yandex.cloud.spark.v1.Cluster\"\x00\x12\x61\n\x04List\x12*.yandex.cloud.spark.v1.ListClustersRequest\x1a+.yandex.cloud.spark.v1.ListClustersResponse\"\x00\x12~\n\x06\x43reate\x12+.yandex.cloud.spark.v1.CreateClusterRequest\x1a!.yandex.cloud.operation.Operation\"$\xb2\xd2* \n\x15\x43reateClusterMetadata\x12\x07\x43luster\x12~\n\x06Update\x12+.yandex.cloud.spark.v1.UpdateClusterRequest\x1a!.yandex.cloud.operation.Operation\"$\xb2\xd2* \n\x15UpdateClusterMetadata\x12\x07\x43luster\x12\x8c\x01\n\x06\x44\x65lete\x12+.yandex.cloud.spark.v1.DeleteClusterRequest\x1a!.yandex.cloud.operation.Operation\"2\xb2\xd2*.\n\x15\x44\x65leteClusterMetadata\x12\x15google.protobuf.Empty\x12{\n\x05Start\x12*.yandex.cloud.spark.v1.StartClusterRequest\x1a!.yandex.cloud.operation.Operation\"#\xb2\xd2*\x1f\n\x14StartClusterMetadata\x12\x07\x43luster\x12x\n\x04Stop\x12).yandex.cloud.spark.v1.StopClusterRequest\x1a!.yandex.cloud.operation.Operation\"\"\xb2\xd2*\x1e\n\x13StopClusterMetadata\x12\x07\x43luster\x12}\n\x0eListOperations\x12\x33.yandex.cloud.spark.v1.ListClusterOperationsRequest\x1a\x34.yandex.cloud.spark.v1.ListClusterOperationsResponse\"\x00\x42\\\n\x19yandex.cloud.api.spark.v1Z?github.com/yandex-cloud/go-genproto/yandex/cloud/spark/v1;sparkb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.spark.v1.cluster_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\031yandex.cloud.api.spark.v1Z?github.com/yandex-cloud/go-genproto/yandex/cloud/spark/v1;spark'
  _globals['_GETCLUSTERREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_GETCLUSTERREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTCLUSTERSREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_LISTCLUSTERSREQUEST'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTCLUSTERSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTCLUSTERSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _globals['_LISTCLUSTERSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTCLUSTERSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=200'
  _globals['_LISTCLUSTERSREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTCLUSTERSREQUEST'].fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _globals['_LISTCLUSTERSRESPONSE'].fields_by_name['next_page_token']._loaded_options = None
  _globals['_LISTCLUSTERSRESPONSE'].fields_by_name['next_page_token']._serialized_options = b'\212\3101\005<=200'
  _globals['_CREATECLUSTERREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_CREATECLUSTERREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['name']._serialized_options = b'\350\3071\001\362\3071\036^[a-z][-a-z0-9]{1,61}[a-z0-9]$\212\3101\004<=63'
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['labels']._loaded_options = None
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\0041-63'
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['config']._loaded_options = None
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['config']._serialized_options = b'\350\3071\001'
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['network']._loaded_options = None
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['network']._serialized_options = b'\350\3071\001'
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['service_account_id']._loaded_options = None
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['service_account_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_CREATECLUSTERMETADATA'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_CREATECLUSTERMETADATA'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001'
  _globals['_UPDATECLUSTERREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_UPDATECLUSTERREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_UPDATECLUSTERREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_UPDATECLUSTERREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_UPDATECLUSTERREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_UPDATECLUSTERREQUEST'].fields_by_name['name']._serialized_options = b'\362\3071\035|[a-z][-a-z0-9]{1,61}[a-z0-9]'
  _globals['_UPDATECLUSTERREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_UPDATECLUSTERREQUEST'].fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _globals['_UPDATECLUSTERREQUEST'].fields_by_name['labels']._loaded_options = None
  _globals['_UPDATECLUSTERREQUEST'].fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\0041-63'
  _globals['_UPDATECLUSTERREQUEST'].fields_by_name['service_account_id']._loaded_options = None
  _globals['_UPDATECLUSTERREQUEST'].fields_by_name['service_account_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_UPDATECLUSTERMETADATA'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_UPDATECLUSTERMETADATA'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_DELETECLUSTERREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_DELETECLUSTERREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_DELETECLUSTERMETADATA'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_DELETECLUSTERMETADATA'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001'
  _globals['_STARTCLUSTERREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_STARTCLUSTERREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_STOPCLUSTERREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_STOPCLUSTERREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTCLUSTEROPERATIONSREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_LISTCLUSTEROPERATIONSREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTCLUSTEROPERATIONSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTCLUSTEROPERATIONSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _globals['_LISTCLUSTEROPERATIONSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTCLUSTEROPERATIONSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=200'
  _globals['_LISTCLUSTEROPERATIONSRESPONSE'].fields_by_name['next_page_token']._loaded_options = None
  _globals['_LISTCLUSTEROPERATIONSRESPONSE'].fields_by_name['next_page_token']._serialized_options = b'\212\3101\005<=200'
  _globals['_CLUSTERSERVICE'].methods_by_name['Create']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['Create']._serialized_options = b'\262\322* \n\025CreateClusterMetadata\022\007Cluster'
  _globals['_CLUSTERSERVICE'].methods_by_name['Update']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['Update']._serialized_options = b'\262\322* \n\025UpdateClusterMetadata\022\007Cluster'
  _globals['_CLUSTERSERVICE'].methods_by_name['Delete']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['Delete']._serialized_options = b'\262\322*.\n\025DeleteClusterMetadata\022\025google.protobuf.Empty'
  _globals['_CLUSTERSERVICE'].methods_by_name['Start']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['Start']._serialized_options = b'\262\322*\037\n\024StartClusterMetadata\022\007Cluster'
  _globals['_CLUSTERSERVICE'].methods_by_name['Stop']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['Stop']._serialized_options = b'\262\322*\036\n\023StopClusterMetadata\022\007Cluster'
  _globals['_GETCLUSTERREQUEST']._serialized_start=287
  _globals['_GETCLUSTERREQUEST']._serialized_end=340
  _globals['_LISTCLUSTERSREQUEST']._serialized_start=343
  _globals['_LISTCLUSTERSREQUEST']._serialized_end=487
  _globals['_LISTCLUSTERSRESPONSE']._serialized_start=489
  _globals['_LISTCLUSTERSRESPONSE']._serialized_end=597
  _globals['_CREATECLUSTERREQUEST']._serialized_start=600
  _globals['_CREATECLUSTERREQUEST']._serialized_end=1248
  _globals['_CREATECLUSTERREQUEST_LABELSENTRY']._serialized_start=1203
  _globals['_CREATECLUSTERREQUEST_LABELSENTRY']._serialized_end=1248
  _globals['_CREATECLUSTERMETADATA']._serialized_start=1250
  _globals['_CREATECLUSTERMETADATA']._serialized_end=1299
  _globals['_UPDATECLUSTERREQUEST']._serialized_start=1302
  _globals['_UPDATECLUSTERREQUEST']._serialized_end=2001
  _globals['_UPDATECLUSTERREQUEST_LABELSENTRY']._serialized_start=1203
  _globals['_UPDATECLUSTERREQUEST_LABELSENTRY']._serialized_end=1248
  _globals['_UPDATECLUSTERMETADATA']._serialized_start=2003
  _globals['_UPDATECLUSTERMETADATA']._serialized_end=2060
  _globals['_DELETECLUSTERREQUEST']._serialized_start=2062
  _globals['_DELETECLUSTERREQUEST']._serialized_end=2118
  _globals['_DELETECLUSTERMETADATA']._serialized_start=2120
  _globals['_DELETECLUSTERMETADATA']._serialized_end=2169
  _globals['_STARTCLUSTERREQUEST']._serialized_start=2171
  _globals['_STARTCLUSTERREQUEST']._serialized_end=2226
  _globals['_STARTCLUSTERMETADATA']._serialized_start=2228
  _globals['_STARTCLUSTERMETADATA']._serialized_end=2270
  _globals['_STOPCLUSTERREQUEST']._serialized_start=2272
  _globals['_STOPCLUSTERREQUEST']._serialized_end=2326
  _globals['_STOPCLUSTERMETADATA']._serialized_start=2328
  _globals['_STOPCLUSTERMETADATA']._serialized_end=2369
  _globals['_LISTCLUSTEROPERATIONSREQUEST']._serialized_start=2371
  _globals['_LISTCLUSTEROPERATIONSREQUEST']._serialized_end=2497
  _globals['_LISTCLUSTEROPERATIONSRESPONSE']._serialized_start=2499
  _globals['_LISTCLUSTEROPERATIONSRESPONSE']._serialized_end=2621
  _globals['_CLUSTERSERVICE']._serialized_start=2624
  _globals['_CLUSTERSERVICE']._serialized_end=3595
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/trino/v1/cluster_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/trino/v1/cluster_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud.trino.v1 import access_control_pb2 as yandex_dot_cloud_dot_trino_dot_v1_dot_access__control__pb2
from yandex.cloud.trino.v1 import catalog_pb2 as yandex_dot_cloud_dot_trino_dot_v1_dot_catalog__pb2
from yandex.cloud.trino.v1 import cluster_pb2 as yandex_dot_cloud_dot_trino_dot_v1_dot_cluster__pb2
from yandex.cloud.trino.v1 import maintenance_pb2 as yandex_dot_cloud_dot_trino_dot_v1_dot_maintenance__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+yandex/cloud/trino/v1/cluster_service.proto\x12\x15yandex.cloud.trino.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\x1a*yandex/cloud/trino/v1/access_control.proto\x1a#yandex/cloud/trino/v1/catalog.proto\x1a#yandex/cloud/trino/v1/cluster.proto\x1a\'yandex/cloud/trino/v1/maintenance.proto\x1a\x1dyandex/cloud/validation.proto\"5\n\x11GetClusterRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\x90\x01\n\x13ListClustersRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"a\n\x14ListClustersResponse\x12\x30\n\x08\x63lusters\x18\x01 \x03(\x0b\x32\x1e.yandex.cloud.trino.v1.Cluster\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xf9\x04\n\x14\x43reateClusterRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12,\n\x04name\x18\x02 \x01(\tB\x1e\xe8\xc7\x31\x01\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x8a\xc8\x31\x04<=63\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x84\x01\n\x06labels\x18\x04 \x03(\x0b\x32\x37.yandex.cloud.trino.v1.CreateClusterRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04\x31-63\x12;\n\x05trino\x18\x05 \x01(\x0b\x32&.yandex.cloud.trino.v1.TrinoConfigSpecB\x04\xe8\xc7\x31\x01\x12;\n\x07network\x18\x06 \x01(\x0b\x32$.yandex.cloud.trino.v1.NetworkConfigB\x04\xe8\xc7\x31\x01\x12\x1b\n\x13\x64\x65letion_protection\x18\x07 \x01(\x08\x12(\n\x12service_account_id\x18\x08 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x35\n\x07logging\x18\t \x01(\x0b\x32$.yandex.cloud.trino.v1.LoggingConfig\x12\x44\n\x12maintenance_window\x18\n \x01(\x0b\x32(.yandex.cloud.trino.v1.MaintenanceWindow\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xf0\x02\n\x0fTrinoConfigSpec\x12\x34\n\x08\x63\x61talogs\x18\x01 \x03(\x0b\x32\".yandex.cloud.trino.v1.CatalogSpec\x12J\n\x12\x63oordinator_config\x18\x02 \x01(\x0b\x32(.yandex.cloud.trino.v1.CoordinatorConfigB\x04\xe8\xc7\x31\x01\x12@\n\rworker_config\x18\x03 \x01(\x0b\x32#.yandex.cloud.trino.v1.WorkerConfigB\x04\xe8\xc7\x31\x01\x12>\n\x0cretry_policy\x18\x04 \x01(\x0b\x32(.yandex.cloud.trino.v1.RetryPolicyConfig\x12\x0f\n\x07version\x18\x06 \x01(\t\x12\x42\n\x0e\x61\x63\x63\x65ss_control\x18\x07 \x01(\x0b\x32*.yandex.cloud.trino.v1.AccessControlConfigJ\x04\x08\x05\x10\x06\"+\n\x15\x43reateClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\"N\n\x17UpdateCoordinatorConfig\x12\x33\n\tresources\x18\x01 \x01(\x0b\x32 .yandex.cloud.trino.v1.Resources\"\xc4\x02\n\x12UpdateWorkerConfig\x12\x33\n\tresources\x18\x01 \x01(\x0b\x32 .yandex.cloud.trino.v1.Resources\x12Q\n\x0cscale_policy\x18\x02 \x01(\x0b\x32;.yandex.cloud.trino.v1.UpdateWorkerConfig.WorkerScalePolicy\x1a\xa5\x01\n\x11WorkerScalePolicy\x12>\n\x0b\x66ixed_scale\x18\x01 \x01(\x0b\x32\'.yandex.cloud.trino.v1.FixedScalePolicyH\x00\x12<\n\nauto_scale\x18\x02 \x01(\x0b\x32&.yandex.cloud.trino.v1.AutoScalePolicyH\x00\x42\x12\n\nscale_type\x12\x04\xc0\xc1\x31\x01\"\xba\x02\n\x15UpdateTrinoConfigSpec\x12J\n\x12\x63oordinator_config\x18\x01 \x01(\x0b\x32..yandex.cloud.trino.v1.UpdateCoordinatorConfig\x12@\n\rworker_config\x18\x02 \x01(\x0b\x32).yandex.cloud.trino.v1.UpdateWorkerConfig\x12\x0f\n\x07version\x18\x03 \x01(\t\x12>\n\x0cretry_policy\x18\x04 \x01(\x0b\x32(.yandex.cloud.trino.v1.RetryPolicyConfig\x12\x42\n\x0e\x61\x63\x63\x65ss_control\x18\x05 \x01(\x0b\x32*.yandex.cloud.trino.v1.AccessControlConfig\"5\n\x17UpdateNetworkConfigSpec\x12\x1a\n\x12security_group_ids\x18\x01 \x03(\t\"\xac\x05\n\x14UpdateClusterRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12(\n\x04name\x18\x03 \x01(\tB\x1a\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x8a\xc8\x31\x04<=63\x12\x1e\n\x0b\x64\x65scription\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x84\x01\n\x06labels\x18\x05 \x03(\x0b\x32\x37.yandex.cloud.trino.v1.UpdateClusterRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04\x31-63\x12\x1b\n\x13\x64\x65letion_protection\x18\x06 \x01(\x08\x12;\n\x05trino\x18\x07 \x01(\x0b\x32,.yandex.cloud.trino.v1.UpdateTrinoConfigSpec\x12\x44\n\x0cnetwork_spec\x18\x08 \x01(\x0b\x32..yandex.cloud.trino.v1.UpdateNetworkConfigSpec\x12$\n\x12service_account_id\x18\t \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x35\n\x07logging\x18\n \x01(\x0b\x32$.yandex.cloud.trino.v1.LoggingConfig\x12\x44\n\x12maintenance_window\x18\x0b \x01(\x0b\x32(.yandex.cloud.trino.v1.MaintenanceWindow\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"+\n\x15UpdateClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\"8\n\x14\x44\x65leteClusterRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"+\n\x15\x44\x65leteClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\"7\n\x13StartClusterRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"*\n\x14StartClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\"6\n\x12StopClusterRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\")\n\x13StopClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\"~\n\x1cListClusterOperationsRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"o\n\x1dListClusterOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\xcc\n\n\x0e\x43lusterService\x12\x80\x01\n\x03Get\x12(.yandex.cloud.trino.v1.GetClusterRequest\x1a\x1e.yandex.cloud.trino.v1.Cluster\"/\x82\xd3\xe4\x93\x02)\x12\'/managed-trino/v1/clusters/{cluster_id}\x12\x83\x01\n\x04List\x12*.yandex.cloud.trino.v1.ListClustersRequest\x1a+.yandex.cloud.trino.v1.ListClustersResponse\"\"\x82\xd3\xe4\x93\x02\x1c\x12\x1a/managed-trino/v1/clusters\x12\xa3\x01\n\x06\x43reate\x12+.yandex.cloud.trino.v1.CreateClusterRequest\x1a!.yandex.cloud.operation.Operation\"I\xb2\xd2* \n\x15\x43reateClusterMetadata\x12\x07\x43luster\x82\xd3\xe4\x93\x02\x1f\"\x1a/managed-trino/v1/clusters:\x01*\x12\xb0\x01\n\x06Update\x12+.yandex.cloud.trino.v1.UpdateClusterRequest\x1a!.yandex.cloud.operation.Operation\"V\xb2\xd2* \n\x15UpdateClusterMetadata\x12\x07\x43luster\x82\xd3\xe4\x93\x02,2\'/managed-trino/v1/clusters/{cluster_id}:\x01*\x12\xbb\x01\n\x06\x44\x65lete\x12+.yandex.cloud.trino.v1.DeleteClusterRequest\x1a!.yandex.cloud.operation.Operation\"a\xb2\xd2*.\n\x15\x44\x65leteClusterMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02)*\'/managed-trino/v1/clusters/{cluster_id}\x12\xb0\x01\n\x05Start\x12*.yandex.cloud.trino.v1.StartClusterRequest\x1a!.yandex.cloud.operation.Operation\"X\xb2\xd2*\x1f\n\x14StartClusterMetadata\x12\x07\x43luster\x82\xd3\xe4\x93\x02/\"-/managed-trino/v1/clusters/{cluster_id}:start\x12\xac\x01\n\x04Stop\x12).yandex.cloud.trino.v1.StopClusterRequest\x1a!.yandex.cloud.operation.Operation\"V\xb2\xd2*\x1e\n\x13StopClusterMetadata\x12\x07\x43luster\x82\xd3\xe4\x93\x02.\",/managed-trino/v1/clusters/{cluster_id}:stop\x12\xb7\x01\n\x0eListOperations\x12\x33.yandex.cloud.trino.v1.ListClusterOperationsRequest\x1a\x34.yandex.cloud.trino.v1.ListClusterOperationsResponse\":\x82\xd3\xe4\x93\x02\x34\x12\x32/managed-trino/v1/clusters/{cluster_id}/operationsB\\\n\x19yandex.cloud.api.trino.v1Z?github.com/yandex-cloud/go-genproto/yandex/cloud/trino/v1;trinob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.trino.v1.cluster_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\031yandex.cloud.api.trino.v1Z?github.com/yandex-cloud/go-genproto/yandex/cloud/trino/v1;trino'
  _globals['_GETCLUSTERREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_GETCLUSTERREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTCLUSTERSREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_LISTCLUSTERSREQUEST'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTCLUSTERSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTCLUSTERSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _globals['_LISTCLUSTERSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTCLUSTERSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_LISTCLUSTERSREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTCLUSTERSREQUEST'].fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _globals['_CREATECLUSTERREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_CREATECLUSTERREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['name']._serialized_options = b'\350\3071\001\362\3071\016[a-zA-Z0-9_-]*\212\3101\004<=63'
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['labels']._loaded_options = None
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\0041-63'
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['trino']._loaded_options = None
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['trino']._serialized_options = b'\350\3071\001'
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['network']._loaded_options = None
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['network']._serialized_options = b'\350\3071\001'
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['service_account_id']._loaded_options = None
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['service_account_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_TRINOCONFIGSPEC'].fields_by_name['coordinator_config']._loaded_options = None
  _globals['_TRINOCONFIGSPEC'].fields_by_name['coordinator_config']._serialized_options = b'\350\3071\001'
  _globals['_TRINOCONFIGSPEC'].fields_by_name['worker_config']._loaded_options = None
  _globals['_TRINOCONFIGSPEC'].fields_by_name['worker_config']._serialized_options = b'\350\3071\001'
  _globals['_UPDATEWORKERCONFIG_WORKERSCALEPOLICY'].oneofs_by_name['scale_type']._loaded_options = None
  _globals['_UPDATEWORKERCONFIG_WORKERSCALEPOLICY'].oneofs_by_name['scale_type']._serialized_options = b'\300\3011\001'
  _globals['_UPDATECLUSTERREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_UPDATECLUSTERREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_UPDATECLUSTERREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_UPDATECLUSTERREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_UPDATECLUSTERREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_UPDATECLUSTERREQUEST'].fields_by_name['name']._serialized_options = b'\362\3071\016[a-zA-Z0-9_-]*\212\3101\004<=63'
  _globals['_UPDATECLUSTERREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_UPDATECLUSTERREQUEST'].fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _globals['_UPDATECLUSTERREQUEST'].fields_by_name['labels']._loaded_options = None
  _globals['_UPDATECLUSTERREQUEST'].fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\0041-63'
  _globals['_UPDATECLUSTERREQUEST'].fields_by_name['service_account_id']._loaded_options = None
  _globals['_UPDATECLUSTERREQUEST'].fields_by_name['service_account_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_DELETECLUSTERREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_DELETECLUSTERREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_STARTCLUSTERREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_STARTCLUSTERREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_STOPCLUSTERREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_STOPCLUSTERREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTCLUSTEROPERATIONSREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_LISTCLUSTEROPERATIONSREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTCLUSTEROPERATIONSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTCLUSTEROPERATIONSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _globals['_LISTCLUSTEROPERATIONSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTCLUSTEROPERATIONSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_CLUSTERSERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\002)\022\'/managed-trino/v1/clusters/{cluster_id}'
  _globals['_CLUSTERSERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\002\034\022\032/managed-trino/v1/clusters'
  _globals['_CLUSTERSERVICE'].methods_by_name['Create']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['Create']._serialized_options = b'\262\322* \n\025CreateClusterMetadata\022\007Cluster\202\323\344\223\002\037\"\032/managed-trino/v1/clusters:\001*'
  _globals['_CLUSTERSERVICE'].methods_by_name['Update']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['Update']._serialized_options = b'\262\322* \n\025UpdateClusterMetadata\022\007Cluster\202\323\344\223\002,2\'/managed-trino/v1/clusters/{cluster_id}:\001*'
  _globals['_CLUSTERSERVICE'].methods_by_name['Delete']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['Delete']._serialized_options = b'\262\322*.\n\025DeleteClusterMetadata\022\025google.protobuf.Empty\202\323\344\223\002)*\'/managed-trino/v1/clusters/{cluster_id}'
  _globals['_CLUSTERSERVICE'].methods_by_name['Start']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['Start']._serialized_options = b'\262\322*\037\n\024StartClusterMetadata\022\007Cluster\202\323\344\223\002/\"-/managed-trino/v1/clusters/{cluster_id}:start'
  _globals['_CLUSTERSERVICE'].methods_by_name['Stop']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['Stop']._serialized_options = b'\262\322*\036\n\023StopClusterMetadata\022\007Cluster\202\323\344\223\002.\",/managed-trino/v1/clusters/{cluster_id}:stop'
  _globals['_CLUSTERSERVICE'].methods_by_name['ListOperations']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['ListOperations']._serialized_options = b'\202\323\344\223\0024\0222/managed-trino/v1/clusters/{cluster_id}/operations'
  _globals['_GETCLUSTERREQUEST']._serialized_start=398
  _globals['_GETCLUSTERREQUEST']._serialized_end=451
  _globals['_LISTCLUSTERSREQUEST']._serialized_start=454
  _globals['_LISTCLUSTERSREQUEST']._serialized_end=598
  _globals['_LISTCLUSTERSRESPONSE']._serialized_start=600
  _globals['_LISTCLUSTERSRESPONSE']._serialized_end=697
  _globals['_CREATECLUSTERREQUEST']._serialized_start=700
  _globals['_CREATECLUSTERREQUEST']._serialized_end=1333
  _globals['_CREATECLUSTERREQUEST_LABELSENTRY']._serialized_start=1288
  _globals['_CREATECLUSTERREQUEST_LABELSENTRY']._serialized_end=1333
  _globals['_TRINOCONFIGSPEC']._serialized_start=1336
  _globals['_TRINOCONFIGSPEC']._serialized_end=1704
  _globals['_CREATECLUSTERMETADATA']._serialized_start=1706
  _globals['_CREATECLUSTERMETADATA']._serialized_end=1749
  _globals['_UPDATECOORDINATORCONFIG']._serialized_start=1751
  _globals['_UPDATECOORDINATORCONFIG']._serialized_end=1829
  _globals['_UPDATEWORKERCONFIG']._serialized_start=1832
  _globals['_UPDATEWORKERCONFIG']._serialized_end=2156
  _globals['_UPDATEWORKERCONFIG_WORKERSCALEPOLICY']._serialized_start=1991
  _globals['_UPDATEWORKERCONFIG_WORKERSCALEPOLICY']._serialized_end=2156
  _globals['_UPDATETRINOCONFIGSPEC']._serialized_start=2159
  _globals['_UPDATETRINOCONFIGSPEC']._serialized_end=2473
  _globals['_UPDATENETWORKCONFIGSPEC']._serialized_start=2475
  _globals['_UPDATENETWORKCONFIGSPEC']._serialized_end=2528
  _globals['_UPDATECLUSTERREQUEST']._serialized_start=2531
  _globals['_UPDATECLUSTERREQUEST']._serialized_end=3215
  _globals['_UPDATECLUSTERREQUEST_LABELSENTRY']._serialized_start=1288
  _globals['_UPDATECLUSTERREQUEST_LABELSENTRY']._serialized_end=1333
  _globals['_UPDATECLUSTERMETADATA']._serialized_start=3217
  _globals['_UPDATECLUSTERMETADATA']._serialized_end=3260
  _globals['_DELETECLUSTERREQUEST']._serialized_start=3262
  _globals['_DELETECLUSTERREQUEST']._serialized_end=3318
  _globals['_DELETECLUSTERMETADATA']._serialized_start=3320
  _globals['_DELETECLUSTERMETADATA']._serialized_end=3363
  _globals['_STARTCLUSTERREQUEST']._serialized_start=3365
  _globals['_STARTCLUSTERREQUEST']._serialized_end=3420
  _globals['_STARTCLUSTERMETADATA']._serialized_start=3422
  _globals['_STARTCLUSTERMETADATA']._serialized_end=3464
  _globals['_STOPCLUSTERREQUEST']._serialized_start=3466
  _globals['_STOPCLUSTERREQUEST']._serialized_end=3520
  _globals['_STOPCLUSTERMETADATA']._serialized_start=3522
  _globals['_STOPCLUSTERMETADATA']._serialized_end=3563
  _globals['_LISTCLUSTEROPERATIONSREQUEST']._serialized_start=3565
  _globals['_LISTCLUSTEROPERATIONSREQUEST']._serialized_end=3691
  _globals['_LISTCLUSTEROPERATIONSRESPONSE']._serialized_start=3693
  _globals['_LISTCLUSTEROPERATIONSRESPONSE']._serialized_end=3804
  _globals['_CLUSTERSERVICE']._serialized_start=3807
  _globals['_CLUSTERSERVICE']._serialized_end=5163
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/mdb/mysql/v1alpha/user.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/mdb/mysql/v1alpha/user.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)yandex/cloud/mdb/mysql/v1alpha/user.proto\x12\x1eyandex.cloud.mdb.mysql.v1alpha\x1a\x1dyandex/cloud/validation.proto\"i\n\x04User\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x12\n\ncluster_id\x18\x02 \x01(\t\x12?\n\x0bpermissions\x18\x03 \x03(\x0b\x32*.yandex.cloud.mdb.mysql.v1alpha.Permission\"\xa4\x03\n\nPermission\x12\x15\n\rdatabase_name\x18\x01 \x01(\t\x12L\n\x05roles\x18\x02 \x03(\x0e\x32\x34.yandex.cloud.mdb.mysql.v1alpha.Permission.PrivilegeB\x07\x82\xc8\x31\x03>=1\"\xb0\x02\n\tPrivilege\x12\x19\n\x15PRIVILEGE_UNSPECIFIED\x10\x00\x12\x12\n\x0e\x41LL_PRIVILEGES\x10\x01\x12\t\n\x05\x41LTER\x10\x02\x12\x11\n\rALTER_ROUTINE\x10\x03\x12\n\n\x06\x43REATE\x10\x04\x12\x12\n\x0e\x43REATE_ROUTINE\x10\x05\x12\x1b\n\x17\x43REATE_TEMPORARY_TABLES\x10\x06\x12\x0f\n\x0b\x43REATE_VIEW\x10\x07\x12\n\n\x06\x44\x45LETE\x10\x08\x12\x08\n\x04\x44ROP\x10\t\x12\t\n\x05\x45VENT\x10\n\x12\x0b\n\x07\x45XECUTE\x10\x0b\x12\t\n\x05INDEX\x10\x0c\x12\n\n\x06INSERT\x10\r\x12\x0f\n\x0bLOCK_TABLES\x10\x0e\x12\n\n\x06SELECT\x10\x0f\x12\r\n\tSHOW_VIEW\x10\x10\x12\x0b\n\x07TRIGGER\x10\x11\x12\n\n\x06UPDATE\x10\x12\"\x99\x01\n\x08UserSpec\x12+\n\x04name\x18\x01 \x01(\tB\x1d\xe8\xc7\x31\x01\xf2\xc7\x31\r[a-zA-Z0-9_]*\x8a\xc8\x31\x04<=32\x12\x1f\n\x08password\x18\x02 \x01(\tB\r\xe8\xc7\x31\x01\x8a\xc8\x31\x05\x38-128\x12?\n\x0bpermissions\x18\x03 \x03(\x0b\x32*.yandex.cloud.mdb.mysql.v1alpha.PermissionBn\n\"yandex.cloud.api.mdb.mysql.v1alphaZHgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/mysql/v1alpha;mysqlb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.mdb.mysql.v1alpha.user_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\"yandex.cloud.api.mdb.mysql.v1alphaZHgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/mysql/v1alpha;mysql'
  _globals['_PERMISSION'].fields_by_name['roles']._loaded_options = None
  _globals['_PERMISSION'].fields_by_name['roles']._serialized_options = b'\202\3101\003>=1'
  _globals['_USERSPEC'].fields_by_name['name']._loaded_options = None
  _globals['_USERSPEC'].fields_by_name['name']._serialized_options = b'\350\3071\001\362\3071\r[a-zA-Z0-9_]*\212\3101\004<=32'
  _globals['_USERSPEC'].fields_by_name['password']._loaded_options = None
  _globals['_USERSPEC'].fields_by_name['password']._serialized_options = b'\350\3071\001\212\3101\0058-128'
  _globals['_USER']._serialized_start=108
  _globals['_USER']._serialized_end=213
  _globals['_PERMISSION']._serialized_start=216
  _globals['_PERMISSION']._serialized_end=636
  _globals['_PERMISSION_PRIVILEGE']._serialized_start=332
  _globals['_PERMISSION_PRIVILEGE']._serialized_end=636
  _globals['_USERSPEC']._serialized_start=639
  _globals['_USERSPEC']._serialized_end=792
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/gitlab/v1/instance.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/gitlab/v1/instance.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.gitlab.v1 import maintenance_pb2 as yandex_dot_cloud_dot_gitlab_dot_v1_dot_maintenance__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%yandex/cloud/gitlab/v1/instance.proto\x12\x16yandex.cloud.gitlab.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1dyandex/cloud/validation.proto\x1a(yandex/cloud/gitlab/v1/maintenance.proto\"\xe0\x07\n\x08Instance\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tfolder_id\x18\x02 \x01(\t\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x06 \x01(\t\x12<\n\x06labels\x18\x07 \x03(\x0b\x32,.yandex.cloud.gitlab.v1.Instance.LabelsEntry\x12\x1a\n\x12resource_preset_id\x18\x08 \x01(\t\x12\x11\n\tdisk_size\x18\t \x01(\x03\x12\x37\n\x06status\x18\n \x01(\x0e\x32\'.yandex.cloud.gitlab.v1.Instance.Status\x12\x13\n\x0b\x61\x64min_login\x18\x0b \x01(\t\x12\x13\n\x0b\x61\x64min_email\x18\x0c \x01(\t\x12\x0e\n\x06\x64omain\x18\r \x01(\t\x12\x11\n\tsubnet_id\x18\x0e \x01(\t\x12M\n\x11planned_operation\x18\x10 \x01(\x0b\x32,.yandex.cloud.gitlab.v1.MaintenanceOperationB\x04\xe8\xc7\x31\x00\x12!\n\x19\x62\x61\x63kup_retain_period_days\x18\x11 \x01(\x03\x12#\n\x1bmaintenance_delete_untagged\x18\x13 \x01(\x08\x12\x1b\n\x13\x64\x65letion_protection\x18\x14 \x01(\x08\x12\'\n\x11\x61pproval_rules_id\x18\x16 \x01(\tB\x0c\xe8\xc7\x31\x00\x8a\xc8\x31\x04<=30\x12\x16\n\x0egitlab_version\x18\x17 \x01(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x88\x02\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x43REATING\x10\x01\x12\x0b\n\x07RUNNING\x10\x02\x12\x0c\n\x08UPDATING\x10\x03\x12\t\n\x05\x45RROR\x10\x04\x12\x0c\n\x08\x44\x45LETING\x10\x05\x12\x13\n\x0f\x42\x41\x43KUP_CREATING\x10\x06\x12\x14\n\x10\x42\x41\x43KUP_RESTORING\x10\x07\x12\x0c\n\x08STARTING\x10\x08\x12\x0c\n\x08STOPPING\x10\t\x12\x0b\n\x07STOPPED\x10\n\x12\x19\n\x15\x42\x41\x43KGROUND_MIGRATIONS\x10\x0b\x12\x1d\n\x19OBJECT_STORAGE_MIGRATIONS\x10\x0c\x12\x16\n\x12SNAPSHOT_RESTORING\x10\rJ\x04\x08\x0f\x10\x10J\x04\x08\x12\x10\x13J\x04\x08\x15\x10\x16\x42\x63\n\x1ayandex.cloud.api.gitlab.v1B\x02GIZAgithub.com/yandex-cloud/go-genproto/yandex/cloud/gitlab/v1;gitlabb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.gitlab.v1.instance_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\032yandex.cloud.api.gitlab.v1B\002GIZAgithub.com/yandex-cloud/go-genproto/yandex/cloud/gitlab/v1;gitlab'
  _globals['_INSTANCE_LABELSENTRY']._loaded_options = None
  _globals['_INSTANCE_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_INSTANCE'].fields_by_name['planned_operation']._loaded_options = None
  _globals['_INSTANCE'].fields_by_name['planned_operation']._serialized_options = b'\350\3071\000'
  _globals['_INSTANCE'].fields_by_name['approval_rules_id']._loaded_options = None
  _globals['_INSTANCE'].fields_by_name['approval_rules_id']._serialized_options = b'\350\3071\000\212\3101\004<=30'
  _globals['_INSTANCE']._serialized_start=172
  _globals['_INSTANCE']._serialized_end=1164
  _globals['_INSTANCE_LABELSENTRY']._serialized_start=834
  _globals['_INSTANCE_LABELSENTRY']._serialized_end=879
  _globals['_INSTANCE_STATUS']._serialized_start=882
  _globals['_INSTANCE_STATUS']._serialized_end=1146
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/mdb/opensearch/v1/extension.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/mdb/opensearch/v1/extension.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.mdb.opensearch.v1.extension import extension_type_pb2 as yandex_dot_cloud_dot_mdb_dot_opensearch_dot_v1_dot_extension_dot_extension__type__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.yandex/cloud/mdb/opensearch/v1/extension.proto\x12\x1eyandex.cloud.mdb.opensearch.v1\x1a\x1dyandex/cloud/validation.proto\x1a=yandex/cloud/mdb/opensearch/v1/extension/extension_type.proto\"\xa1\x01\n\tExtension\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x12\n\ncluster_id\x18\x03 \x01(\t\x12\x0f\n\x07version\x18\x04 \x01(\x03\x12\x0e\n\x06\x61\x63tive\x18\x05 \x01(\x08\x12\x45\n\x04type\x18\x06 \x01(\x0e\x32\x37.yandex.cloud.mdb.opensearch.v1.extension.ExtensionType\"\xa5\x01\n\rExtensionSpec\x12\x1a\n\x04name\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x19\n\x03uri\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x10\n\x08\x64isabled\x18\x03 \x01(\x08\x12K\n\x04type\x18\x04 \x01(\x0e\x32\x37.yandex.cloud.mdb.opensearch.v1.extension.ExtensionTypeB\x04\xe8\xc7\x31\x01\x42s\n\"yandex.cloud.api.mdb.opensearch.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/opensearch/v1;opensearchb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.mdb.opensearch.v1.extension_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\"yandex.cloud.api.mdb.opensearch.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/opensearch/v1;opensearch'
  _globals['_EXTENSIONSPEC'].fields_by_name['name']._loaded_options = None
  _globals['_EXTENSIONSPEC'].fields_by_name['name']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_EXTENSIONSPEC'].fields_by_name['uri']._loaded_options = None
  _globals['_EXTENSIONSPEC'].fields_by_name['uri']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_EXTENSIONSPEC'].fields_by_name['type']._loaded_options = None
  _globals['_EXTENSIONSPEC'].fields_by_name['type']._serialized_options = b'\350\3071\001'
  _globals['_EXTENSION']._serialized_start=177
  _globals['_EXTENSION']._serialized_end=338
  _globals['_EXTENSIONSPEC']._serialized_start=341
  _globals['_EXTENSIONSPEC']._serialized_end=506
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/speechsense/v1/analysis/interrupts_statistics.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/speechsense/v1/analysis/interrupts_statistics.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud.speechsense.v1.analysis import statistics_common_pb2 as yandex_dot_cloud_dot_speechsense_dot_v1_dot_analysis_dot_statistics__common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n@yandex/cloud/speechsense/v1/analysis/interrupts_statistics.proto\x12$yandex.cloud.speechsense.v1.analysis\x1a<yandex/cloud/speechsense/v1/analysis/statistics_common.proto\"n\n\x14InterruptsStatistics\x12V\n\x12speaker_interrupts\x18\x01 \x03(\x0b\x32:.yandex.cloud.speechsense.v1.analysis.InterruptsEvaluation\"\xdc\x01\n\x14InterruptsEvaluation\x12\x13\n\x0bspeaker_tag\x18\x01 \x01(\t\x12\x18\n\x10interrupts_count\x18\x02 \x01(\x03\x12\x1e\n\x16interrupts_duration_ms\x18\x03 \x01(\x03\x12P\n\ninterrupts\x18\x04 \x03(\x0b\x32<.yandex.cloud.speechsense.v1.analysis.AudioSegmentBoundaries\x12#\n\x1binterrupts_duration_seconds\x18\x05 \x01(\x03\x42\x9b\x01\n(yandex.cloud.api.speechsense.v1.analysisB\x19InterruptsStatisticsProtoZTgithub.com/yandex-cloud/go-genproto/yandex/cloud/speechsense/v1/analysis;speechsenseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.speechsense.v1.analysis.interrupts_statistics_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n(yandex.cloud.api.speechsense.v1.analysisB\031InterruptsStatisticsProtoZTgithub.com/yandex-cloud/go-genproto/yandex/cloud/speechsense/v1/analysis;speechsense'
  _globals['_INTERRUPTSSTATISTICS']._serialized_start=168
  _globals['_INTERRUPTSSTATISTICS']._serialized_end=278
  _globals['_INTERRUPTSEVALUATION']._serialized_start=281
  _globals['_INTERRUPTSEVALUATION']._serialized_end=501
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/oauth/claims.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/oauth/claims.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1fyandex/cloud/oauth/claims.proto\x12\x12yandex.cloud.oauth\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1dyandex/cloud/validation.proto\"\xad\x03\n\rSubjectClaims\x12\x19\n\x03sub\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x12\n\ngiven_name\x18\x03 \x01(\t\x12\x13\n\x0b\x66\x61mily_name\x18\x04 \x01(\t\x12\x1a\n\x12preferred_username\x18\x07 \x01(\t\x12\x0f\n\x07picture\x18\t \x01(\t\x12\r\n\x05\x65mail\x18\x0b \x01(\t\x12\x10\n\x08zoneinfo\x18\x0f \x01(\t\x12\x0e\n\x06locale\x18\x10 \x01(\t\x12\x14\n\x0cphone_number\x18\x11 \x01(\t\x12\x31\n\x08sub_type\x18\x63 \x01(\x0e\x32\x1f.yandex.cloud.oauth.SubjectType\x12\x32\n\nfederation\x18\x64 \x01(\x0b\x32\x1e.yandex.cloud.oauth.Federation\x12\x39\n\x15last_authenticated_at\x18i \x01(\x0b\x32\x1a.google.protobuf.TimestampJ\x04\x08\x08\x10\tJ\x04\x08\n\x10\x0bJ\x04\x08\x0c\x10\x0fJ\x04\x08\x12\x10\x63J\x04\x08\x05\x10\x07J\x04\x08\x65\x10\x66J\x04\x08\x66\x10gJ\x04\x08g\x10hJ\x04\x08h\x10i\":\n\nFederation\x12\x18\n\x02id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x0c\n\x04name\x18\x03 \x01(\tJ\x04\x08\x02\x10\x03*j\n\x0bSubjectType\x12\x1c\n\x18SUBJECT_TYPE_UNSPECIFIED\x10\x00\x12\x10\n\x0cUSER_ACCOUNT\x10\x01\x12\x13\n\x0fSERVICE_ACCOUNT\x10\x02\x12\t\n\x05GROUP\x10\x03\x12\x0b\n\x07INVITEE\x10\x04\x42Y\n\x19yandex.cloud.api.oauth.v1Z<github.com/yandex-cloud/go-genproto/yandex/cloud/oauth;oauthb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.oauth.claims_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\031yandex.cloud.api.oauth.v1Z<github.com/yandex-cloud/go-genproto/yandex/cloud/oauth;oauth'
  _globals['_SUBJECTCLAIMS'].fields_by_name['sub']._loaded_options = None
  _globals['_SUBJECTCLAIMS'].fields_by_name['sub']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_FEDERATION'].fields_by_name['id']._loaded_options = None
  _globals['_FEDERATION'].fields_by_name['id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_SUBJECTTYPE']._serialized_start=611
  _globals['_SUBJECTTYPE']._serialized_end=717
  _globals['_SUBJECTCLAIMS']._serialized_start=120
  _globals['_SUBJECTCLAIMS']._serialized_end=549
  _globals['_FEDERATION']._serialized_start=551
  _globals['_FEDERATION']._serialized_end=609
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from yandex.cloud.serverless.functions.v1 import network_service_pb2 as yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_network__service__pb2

GRPC_GENERATED_VERSION = '1.70.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in yandex/cloud/serverless/functions/v1/network_service_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class NetworkServiceStub(object):
    """A set of methods for managing VPC networks connected to serverless resources.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetUsed = channel.unary_unary(
                '/yandex.cloud.serverless.functions.v1.NetworkService/GetUsed',
                request_serializer=yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_network__service__pb2.GetUsedNetworkRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_network__service__pb2.UsedNetwork.FromString,
                _registered_method=True)
        self.ListUsed = channel.unary_unary(
                '/yandex.cloud.serverless.functions.v1.NetworkService/ListUsed',
                request_serializer=yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_network__service__pb2.ListUsedNetworksRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_network__service__pb2.ListUsedNetworksResponse.FromString,
                _registered_method=True)
        self.ListConnectedResources = channel.unary_unary(
                '/yandex.cloud.serverless.functions.v1.NetworkService/ListConnectedResources',
                request_serializer=yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_network__service__pb2.ListConnectedResourcesRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_network__service__pb2.ListConnectedResourcesResponse.FromString,
                _registered_method=True)
        self.TriggerUsedCleanup = channel.unary_unary(
                '/yandex.cloud.serverless.functions.v1.NetworkService/TriggerUsedCleanup',
                request_serializer=yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_network__service__pb2.TriggerUsedNetworkCleanupRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_network__service__pb2.TriggerUsedNetworkCleanupResponse.FromString,
                _registered_method=True)


class NetworkServiceServicer(object):
    """A set of methods for managing VPC networks connected to serverless resources.
    """

    def GetUsed(self, request, context):
        """Returns the specified network used in serverless resources.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListUsed(self, request, context):
        """Retrieves the list of networks in the specified scope that are used in serverless resources.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListConnectedResources(self, request, context):
        """Retrieves the list of serverless resources connected to any network from the specified scope.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TriggerUsedCleanup(self, request, context):
        """Forces obsolete used network to start cleanup process as soon as possible.
        Invocation does not wait for start or end of the cleanup process.
        Second invocation with the same network does nothing until network is completely cleaned-up.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_NetworkServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetUsed': grpc.unary_unary_rpc_method_handler(
                    servicer.GetUsed,
                    request_deserializer=yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_network__service__pb2.GetUsedNetworkRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_network__service__pb2.UsedNetwork.SerializeToString,
            ),
            'ListUsed': grpc.unary_unary_rpc_method_handler(
                    servicer.ListUsed,
                    request_deserializer=yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_network__service__pb2.ListUsedNetworksRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_network__service__pb2.ListUsedNetworksResponse.SerializeToString,
            ),
            'ListConnectedResources': grpc.unary_unary_rpc_method_handler(
                    servicer.ListConnectedResources,
                    request_deserializer=yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_network__service__pb2.ListConnectedResourcesRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_network__service__pb2.ListConnectedResourcesResponse.SerializeToString,
            ),
            'TriggerUsedCleanup': grpc.unary_unary_rpc_method_handler(
                    servicer.TriggerUsedCleanup,
                    request_deserializer=yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_network__service__pb2.TriggerUsedNetworkCleanupRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_network__service__pb2.TriggerUsedNetworkCleanupResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'yandex.cloud.serverless.functions.v1.NetworkService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('yandex.cloud.serverless.functions.v1.NetworkService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class NetworkService(object):
    """A set of methods for managing VPC networks connected to serverless resources.
    """

    @staticmethod
    def GetUsed(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.serverless.functions.v1.NetworkService/GetUsed',
            yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_network__service__pb2.GetUsedNetworkRequest.SerializeToString,
            yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_network__service__pb2.UsedNetwork.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListUsed(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.serverless.functions.v1.NetworkService/ListUsed',
            yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_network__service__pb2.ListUsedNetworksRequest.SerializeToString,
            yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_network__service__pb2.ListUsedNetworksResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListConnectedResources(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.serverless.functions.v1.NetworkService/ListConnectedResources',
            yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_network__service__pb2.ListConnectedResourcesRequest.SerializeToString,
            yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_network__service__pb2.ListConnectedResourcesResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def TriggerUsedCleanup(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.serverless.functions.v1.NetworkService/TriggerUsedCleanup',
            yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_network__service__pb2.TriggerUsedNetworkCleanupRequest.SerializeToString,
            yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_network__service__pb2.TriggerUsedNetworkCleanupResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)
